powered by
Check if the NeuroimaGene database exists in the proper location prior to running the query and prompt user to download if not.
check_db(timeout = 900)
no return value, called to give information on status of neuroimaGene database and prompt user the user to download if resource file is missing.
time to spend downloading the NeuroimaGene database in seconds (default = 900)
check_db(timeout = 600)
Run the code above in your browser using DataLab