neuro_vis: 2D visualization plot of a neuroimaGene object
Description
Generates a 2D visualization plot of the neuroimaGene object. Neuroimaging
regions are defined by the atlas parameter and colored according to the
magnitude and direction of the aggregate effect from each gene in the
NeuroimaGene object. Colors can be defined by the user.
Usage
neuro_vis(
ng_obj,
atlas = "Desikan",
lowcol = "red2",
midcol = "white",
highcol = "royalblue2",
title = NA
)
Value
class: ggplot object depicting 2D visualization of the NIDPs from the neuroimaGene object portrayed on the brain and shaded by mean effect size.
Arguments
ng_obj
NeuroimaGene object produced by neuroimaGene() function
atlas
desired atlas for visualization. Desikan (default), Subcortex, DKT, Destrieux.
lowcol
color for low end of Zscore spectrum. Default is dark red
midcol
color for middle of Zscore spectrum. Default is white
highcol
color for top end of Zscore spectrum. Default is blue4